@@ -17,8 +17,8 @@ use SHARYANTO::Package::Util qw(package_exists);
 use Tie::Cache;
 use URI::Split qw(uri_split uri_join);
 
-our $VERSION = '0.67'; # VERSION
-our $DATE = '2014-05-17'; # DATE
+our $VERSION = '0.68'; # VERSION
+our $DATE = '2014-06-18'; # DATE
 
 our $re_perl_package =
     qr/\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_][A-Za-z_0-9]*)*\z/;
@@ -56,7 +56,7 @@ sub new {
     }
     $self->{_typeacts} = \%typeacts;
 
-    $self->{cache_size}              //= 100; # for caching metadata & coded
+    $self->{cache_size}              //= 100; # for caching metadata & code
     #$self->{use_tx}                  //= 0;
     $self->{wrap}                    //= 1;
     #$self->{custom_tx_manager}       //= undef;
@@ -718,6 +718,29 @@ sub action_complete_arg_val {
                                               arg=>$arg, ci=>$ci) // []];
 }
 
+sub actionmeta_complete_arg_elem { +{
+    applies_to => ['function'],
+    summary    => "Complete function's argument element value"
+} }
+
+sub action_complete_arg_elem {
+    require Perinci::Sub::Complete;
+
+    my ($self, $req) = @_;
+    my $arg = $req->{arg} or return err(400, "Please specify arg");
+    defined(my $index = $req->{index})
+        or return err(400, "Please specify index");
+    my $word = $req->{word} // "";
+    my $ci = $req->{ci};
+
+    my $res = $self->get_meta($req);
+    return $res if $res;
+    [200, "OK (complete_arg_elem action)",
+     Perinci::Sub::Complete::complete_arg_elem(
+         meta=>$req->{-meta}, word=>$word, arg=>$arg, ci=>$ci, index=>$index,
+     ) // []],
+}
+
 sub actionmeta_child_metas { +{
     applies_to => ['package'],
     summary    => "Get metadata of all child entities",
@@ -977,7 +1000,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.67 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2014-05-17.
+This document describes version 0.68 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2014-06-18.
 
 =head1 DESCRIPTION
 
